KafkaBatcher.Behaviours.Producer behaviour (kafka_batcher v1.1.1)
KafkaBatcher.Behaviours.Producer adds an abstraction level over producer implementations in various Kafka libs. Defines the callbacks that a Kafka producer should implement
Summary
Types
@type event() :: KafkaBatcher.MessageObject.t()
@type events() :: [event()]