KafkaBatcher.Config (kafka_batcher v1.1.1)
KafkaBatcher configuration processing. All config parameters are described in details in README.md Examples of configs can be found in the files config/test.exs and test/support/collectors/collector_handlers.ex
Summary
Functions
Return all configured topics with its config.
Types
@type sasl_mechanism() :: :plain | :scram_sha_256 | :scram_sha_512
@type sasl_type() :: {sasl_mechanism(), binary(), binary()} | :undefined
Functions
@spec collectors_spec() :: [:supervisor.child_spec()]
@spec general_producer_config() :: Keyword.t()
Return all configured topics with its config.
@spec get_endpoints() :: [{binary(), non_neg_integer()}]
@spec get_endpoints(config :: Keyword.t()) :: [{binary(), non_neg_integer()}]